---
title: How to build multi-tenant apps in Next.js
nav_title: Multi-tenant
description: Learn how to build multi-tenant apps with the App Router.
---

If you are looking to build a single Next.js application that serves multiple tenants, we have [built an example](https://vercel.com/templates/next.js/platforms-starter-kit) showing our recommended architecture.
